--- src/sidebarchartsbrowser.cpp.orig	2022-03-24 04:51:12 UTC
+++ src/sidebarchartsbrowser.cpp
@@ -34,6 +34,7 @@
 #include <QVBoxLayout>
 
 #include <qwt_plot_curve.h>
+#include <qwt_text.h>
 
 namespace Caneda
 {
