--- src/KeyHandler.cpp.orig	2024-05-06 03:07:04 UTC
+++ src/KeyHandler.cpp
@@ -25,6 +25,7 @@
 
 #include <algorithm>
 #include <chrono>
+#include <sstream>
 #include <utility>
 
 #include "ChineseNumbers/ChineseNumbers.h"
