--- app/src/usb/aoa_hid.h.orig	2024-03-02 22:22:09 UTC
+++ app/src/usb/aoa_hid.h
@@ -4,7 +4,7 @@
 #include <stdint.h>
 #include <stdbool.h>
 
-#include <libusb-1.0/libusb.h>
+#include <libusb.h>
 
 #include "hid/hid_event.h"
 #include "usb.h"
